__author__ = 'wangjian'

freq_1m = \
     [
      # '21:00:00',
      '21:01:00', '21:02:00', '21:03:00', '21:04:00', '21:05:00', '21:06:00', '21:07:00', '21:08:00', '21:09:00', '21:10:00',
      '21:11:00', '21:12:00', '21:13:00', '21:14:00', '21:15:00', '21:16:00', '21:17:00', '21:18:00', '21:19:00', '21:20:00',
      '21:21:00', '21:22:00', '21:23:00', '21:24:00', '21:25:00', '21:26:00', '21:27:00', '21:28:00', '21:29:00', '21:30:00',
      '21:31:00', '21:32:00', '21:33:00', '21:34:00', '21:35:00', '21:36:00', '21:37:00', '21:38:00', '21:39:00', '21:40:00',
      '21:41:00', '21:42:00', '21:43:00', '21:44:00', '21:45:00', '21:46:00', '21:47:00', '21:48:00', '21:49:00', '21:50:00',
      '21:51:00', '21:52:00', '21:53:00', '21:54:00', '21:55:00', '21:56:00', '21:57:00', '21:58:00', '21:59:00', '22:00:00',
      '22:01:00', '22:02:00', '22:03:00', '22:04:00', '22:05:00', '22:06:00', '22:07:00', '22:08:00', '22:09:00', '22:10:00',
      '22:11:00', '22:12:00', '22:13:00', '22:14:00', '22:15:00', '22:16:00', '22:17:00', '22:18:00', '22:19:00', '22:20:00',
      '22:21:00', '22:22:00', '22:23:00', '22:24:00', '22:25:00', '22:26:00', '22:27:00', '22:28:00', '22:29:00', '22:30:00',
      '22:31:00', '22:32:00', '22:33:00', '22:34:00', '22:35:00', '22:36:00', '22:37:00', '22:38:00', '22:39:00', '22:40:00',
      '22:41:00', '22:42:00', '22:43:00', '22:44:00', '22:45:00', '22:46:00', '22:47:00', '22:48:00', '22:49:00', '22:50:00',
      '22:51:00', '22:52:00', '22:53:00', '22:54:00', '22:55:00', '22:56:00', '22:57:00', '22:58:00', '22:59:00', '23:00:00',
      '23:01:00', '23:02:00', '23:03:00', '23:04:00', '23:05:00', '23:06:00', '23:07:00', '23:08:00', '23:09:00', '23:10:00',
      '23:11:00', '23:12:00', '23:13:00', '23:14:00', '23:15:00', '23:16:00', '23:17:00', '23:18:00', '23:19:00', '23:20:00',
      '23:21:00', '23:22:00', '23:23:00', '23:24:00', '23:25:00', '23:26:00', '23:27:00', '23:28:00', '23:29:00', '23:30:00',
      '23:31:00', '23:32:00', '23:33:00', '23:34:00', '23:35:00', '23:36:00', '23:37:00', '23:38:00', '23:39:00', '23:40:00',
      '23:41:00', '23:42:00', '23:43:00', '23:44:00', '23:45:00', '23:46:00', '23:47:00', '23:48:00', '23:49:00', '23:50:00',
      '23:51:00', '23:52:00', '23:53:00', '23:54:00', '23:55:00', '23:56:00', '23:57:00', '23:58:00', '23:59:00',

      '00:00:00',
      '00:01:00', '00:02:00', '00:03:00', '00:04:00', '00:05:00', '00:06:00', '00:07:00', '00:08:00', '00:09:00', '00:10:00',
      '00:11:00', '00:12:00', '00:13:00', '00:14:00', '00:15:00', '00:16:00', '00:17:00', '00:18:00', '00:19:00', '00:20:00',
      '00:21:00', '00:22:00', '00:23:00', '00:24:00', '00:25:00', '00:26:00', '00:27:00', '00:28:00', '00:29:00', '00:30:00',
      '00:31:00', '00:32:00', '00:33:00', '00:34:00', '00:35:00', '00:36:00', '00:37:00', '00:38:00', '00:39:00', '00:40:00',
      '00:41:00', '00:42:00', '00:43:00', '00:44:00', '00:45:00', '00:46:00', '00:47:00', '00:48:00', '00:49:00', '00:50:00',
      '00:51:00', '00:52:00', '00:53:00', '00:54:00', '00:55:00', '00:56:00', '00:57:00', '00:58:00', '00:59:00', '01:00:00',
      '01:01:00', '01:02:00', '01:03:00', '01:04:00', '01:05:00', '01:06:00', '01:07:00', '01:08:00', '01:09:00', '01:10:00',
      '01:11:00', '01:12:00', '01:13:00', '01:14:00', '01:15:00', '01:16:00', '01:17:00', '01:18:00', '01:19:00', '01:20:00',
      '01:21:00', '01:22:00', '01:23:00', '01:24:00', '01:25:00', '01:26:00', '01:27:00', '01:28:00', '01:29:00', '01:30:00',
      '01:31:00', '01:32:00', '01:33:00', '01:34:00', '01:35:00', '01:36:00', '01:37:00', '01:38:00', '01:39:00', '01:40:00',
      '01:41:00', '01:42:00', '01:43:00', '01:44:00', '01:45:00', '01:46:00', '01:47:00', '01:48:00', '01:49:00', '01:50:00',
      '01:51:00', '01:52:00', '01:53:00', '01:54:00', '01:55:00', '01:56:00', '01:57:00', '01:58:00', '01:59:00', '02:00:00',

      # '09:00:00',
                  '09:02:00', '09:03:00', '09:04:00', '09:05:00', '09:06:00', '09:07:00', '09:08:00', '09:09:00', '09:10:00',
      '09:11:00', '09:12:00', '09:13:00', '09:14:00', '09:15:00', '09:16:00', '09:17:00', '09:18:00', '09:19:00', '09:20:00',
      '09:21:00', '09:22:00', '09:23:00', '09:24:00', '09:25:00', '09:26:00', '09:27:00', '09:28:00', '09:29:00', '09:30:00',
      '09:31:00', '09:32:00', '09:33:00', '09:34:00', '09:35:00', '09:36:00', '09:37:00', '09:38:00', '09:39:00', '09:40:00',
      '09:41:00', '09:42:00', '09:43:00', '09:44:00', '09:45:00', '09:46:00', '09:47:00', '09:48:00', '09:49:00', '09:50:00',
      '09:51:00', '09:52:00', '09:53:00', '09:54:00', '09:55:00', '09:56:00', '09:57:00', '09:58:00', '09:59:00', '10:00:00',
      '10:01:00', '10:02:00', '10:03:00', '10:04:00', '10:05:00', '10:06:00', '10:07:00', '10:08:00', '10:09:00', '10:10:00',
      '10:11:00', '10:12:00', '10:13:00', '10:14:00', '10:15:00',
      # '10:30:00',
      '10:31:00', '10:32:00', '10:33:00', '10:34:00', '10:35:00', '10:36:00', '10:37:00', '10:38:00', '10:39:00', '10:40:00',
      '10:41:00', '10:42:00', '10:43:00', '10:44:00', '10:45:00', '10:46:00', '10:47:00', '10:48:00', '10:49:00', '10:50:00',
      '10:51:00', '10:52:00', '10:53:00', '10:54:00', '10:55:00', '10:56:00', '10:57:00', '10:58:00', '10:59:00', '11:00:00',
      '11:01:00', '11:02:00', '11:03:00', '11:04:00', '11:05:00', '11:06:00', '11:07:00', '11:08:00', '11:09:00', '11:10:00',
      '11:11:00', '11:12:00', '11:13:00', '11:14:00', '11:15:00', '11:16:00', '11:17:00', '11:18:00', '11:19:00', '11:20:00',
      '11:21:00', '11:22:00', '11:23:00', '11:24:00', '11:25:00', '11:26:00', '11:27:00', '11:28:00', '11:29:00', '11:30:00',

      # '13:30:00',
      '13:31:00', '13:32:00', '13:33:00', '13:34:00', '13:35:00', '13:36:00', '13:37:00', '13:38:00', '13:39:00', '13:40:00',
      '13:41:00', '13:42:00', '13:43:00', '13:44:00', '13:45:00', '13:46:00', '13:47:00', '13:48:00', '13:49:00', '13:50:00',
      '13:51:00', '13:52:00', '13:53:00', '13:54:00', '13:55:00', '13:56:00', '13:57:00', '13:58:00', '13:59:00', '14:00:00',
      '14:01:00', '14:02:00', '14:03:00', '14:04:00', '14:05:00', '14:06:00', '14:07:00', '14:08:00', '14:09:00', '14:10:00',
      '14:11:00', '14:12:00', '14:13:00', '14:14:00', '14:15:00', '14:16:00', '14:17:00', '14:18:00', '14:19:00', '14:20:00',
      '14:21:00', '14:22:00', '14:23:00', '14:24:00', '14:25:00', '14:26:00', '14:27:00', '14:28:00', '14:29:00', '14:30:00',
      '14:31:00', '14:32:00', '14:33:00', '14:34:00', '14:35:00', '14:36:00', '14:37:00', '14:38:00', '14:39:00', '14:40:00',
      '14:41:00', '14:42:00', '14:43:00', '14:44:00', '14:45:00', '14:46:00', '14:47:00', '14:48:00', '14:49:00', '14:50:00',
      '14:51:00', '14:52:00', '14:53:00', '14:54:00', '14:55:00', '14:56:00', '14:57:00', '14:58:00', '14:59:00',
     ]



freq_1m_sim = \
     [
      # '21:00:00',
      '21:01:00', '21:02:00', '21:03:00', '21:04:00', '21:05:00', '21:06:00', '21:07:00', '21:08:00', '21:09:00', '21:10:00',
      '21:11:00', '21:12:00', '21:13:00', '21:14:00', '21:15:00', '21:16:00', '21:17:00', '21:18:00', '21:19:00', '21:20:00',
      '21:21:00', '21:22:00', '21:23:00', '21:24:00', '21:25:00', '21:26:00', '21:27:00', '21:28:00', '21:29:00', '21:30:00',
      '21:31:00', '21:32:00', '21:33:00', '21:34:00', '21:35:00', '21:36:00', '21:37:00', '21:38:00', '21:39:00', '21:40:00',
      '21:41:00', '21:42:00', '21:43:00', '21:44:00', '21:45:00', '21:46:00', '21:47:00', '21:48:00', '21:49:00', '21:50:00',
      '21:51:00', '21:52:00', '21:53:00', '21:54:00', '21:55:00', '21:56:00', '21:57:00', '21:58:00', '21:59:00', '22:00:00',
      '22:01:00', '22:02:00', '22:03:00', '22:04:00', '22:05:00', '22:06:00', '22:07:00', '22:08:00', '22:09:00', '22:10:00',
      '22:11:00', '22:12:00', '22:13:00', '22:14:00', '22:15:00', '22:16:00', '22:17:00', '22:18:00', '22:19:00', '22:20:00',
      '22:21:00', '22:22:00', '22:23:00', '22:24:00', '22:25:00', '22:26:00', '22:27:00', '22:28:00', '22:29:00', '22:30:00',
      '22:31:00', '22:32:00', '22:33:00', '22:34:00', '22:35:00', '22:36:00', '22:37:00', '22:38:00', '22:39:00', '22:40:00',
      '22:41:00', '22:42:00', '22:43:00', '22:44:00', '22:45:00', '22:46:00', '22:47:00', '22:48:00', '22:49:00', '22:50:00',
      '22:51:00', '22:52:00', '22:53:00', '22:54:00', '22:55:00', '22:56:00', '22:57:00', '22:58:00', '22:59:00', '23:00:00',
      '23:01:00', '23:02:00', '23:03:00', '23:04:00', '23:05:00', '23:06:00', '23:07:00', '23:08:00', '23:09:00', '23:10:00',
      '23:11:00', '23:12:00', '23:13:00', '23:14:00', '23:15:00', '23:16:00', '23:17:00', '23:18:00', '23:19:00', '23:20:00',
      '23:21:00', '23:22:00', '23:23:00', '23:24:00', '23:25:00', '23:26:00', '23:27:00', '23:28:00', '23:29:00', '23:30:00',
      '23:31:00', '23:32:00', '23:33:00', '23:34:00', '23:35:00', '23:36:00', '23:37:00', '23:38:00', '23:39:00', '23:40:00',
      '23:41:00', '23:42:00', '23:43:00', '23:44:00', '23:45:00', '23:46:00', '23:47:00', '23:48:00', '23:49:00', '23:50:00',
      '23:51:00', '23:52:00', '23:53:00', '23:54:00', '23:55:00', '23:56:00', '23:57:00', '23:58:00', '23:59:00',

      '00:00:00',
      '00:01:00', '00:02:00', '00:03:00', '00:04:00', '00:05:00', '00:06:00', '00:07:00', '00:08:00', '00:09:00', '00:10:00',
      '00:11:00', '00:12:00', '00:13:00', '00:14:00', '00:15:00', '00:16:00', '00:17:00', '00:18:00', '00:19:00', '00:20:00',
      '00:21:00', '00:22:00', '00:23:00', '00:24:00', '00:25:00', '00:26:00', '00:27:00', '00:28:00', '00:29:00', '00:30:00',
      '00:31:00', '00:32:00', '00:33:00', '00:34:00', '00:35:00', '00:36:00', '00:37:00', '00:38:00', '00:39:00', '00:40:00',
      '00:41:00', '00:42:00', '00:43:00', '00:44:00', '00:45:00', '00:46:00', '00:47:00', '00:48:00', '00:49:00', '00:50:00',
      '00:51:00', '00:52:00', '00:53:00', '00:54:00', '00:55:00', '00:56:00', '00:57:00', '00:58:00', '00:59:00', '01:00:00',
      '01:01:00', '01:02:00', '01:03:00', '01:04:00', '01:05:00', '01:06:00', '01:07:00', '01:08:00', '01:09:00', '01:10:00',
      '01:11:00', '01:12:00', '01:13:00', '01:14:00', '01:15:00', '01:16:00', '01:17:00', '01:18:00', '01:19:00', '01:20:00',
      '01:21:00', '01:22:00', '01:23:00', '01:24:00', '01:25:00', '01:26:00', '01:27:00', '01:28:00', '01:29:00', '01:30:00',
      '01:31:00', '01:32:00', '01:33:00', '01:34:00', '01:35:00', '01:36:00', '01:37:00', '01:38:00', '01:39:00', '01:40:00',
      '01:41:00', '01:42:00', '01:43:00', '01:44:00', '01:45:00', '01:46:00', '01:47:00', '01:48:00', '01:49:00', '01:50:00',
      '01:51:00', '01:52:00', '01:53:00', '01:54:00', '01:55:00', '01:56:00', '01:57:00', '01:58:00', '01:59:00', '02:00:00',
      '02:01:00', '02:02:00', '02:03:00', '02:04:00', '02:05:00', '02:06:00', '02:07:00', '02:08:00', '02:09:00', '02:10:00',
      '02:11:00', '02:12:00', '02:13:00', '02:14:00', '02:15:00', '02:16:00', '02:17:00', '02:18:00', '02:19:00', '02:20:00',
      '02:21:00', '02:22:00', '02:23:00', '02:24:00', '02:25:00', '02:26:00', '02:27:00', '02:28:00', '02:29:00',

      # '09:00:00',
      '09:01:00', '09:02:00', '09:03:00', '09:04:00', '09:05:00', '09:06:00', '09:07:00', '09:08:00', '09:09:00', '09:10:00',
      '09:11:00', '09:12:00', '09:13:00', '09:14:00', '09:15:00', '09:16:00', '09:17:00', '09:18:00', '09:19:00', '09:20:00',
      '09:21:00', '09:22:00', '09:23:00', '09:24:00', '09:25:00', '09:26:00', '09:27:00', '09:28:00', '09:29:00', '09:30:00',
      '09:31:00', '09:32:00', '09:33:00', '09:34:00', '09:35:00', '09:36:00', '09:37:00', '09:38:00', '09:39:00', '09:40:00',
      '09:41:00', '09:42:00', '09:43:00', '09:44:00', '09:45:00', '09:46:00', '09:47:00', '09:48:00', '09:49:00', '09:50:00',
      '09:51:00', '09:52:00', '09:53:00', '09:54:00', '09:55:00', '09:56:00', '09:57:00', '09:58:00', '09:59:00', '10:00:00',
      '10:01:00', '10:02:00', '10:03:00', '10:04:00', '10:05:00', '10:06:00', '10:07:00', '10:08:00', '10:09:00', '10:10:00',
      '10:11:00', '10:12:00', '10:13:00', '10:14:00',
      # '10:30:00',
      '10:31:00', '10:32:00', '10:33:00', '10:34:00', '10:35:00', '10:36:00', '10:37:00', '10:38:00', '10:39:00', '10:40:00',
      '10:41:00', '10:42:00', '10:43:00', '10:44:00', '10:45:00', '10:46:00', '10:47:00', '10:48:00', '10:49:00', '10:50:00',
      '10:51:00', '10:52:00', '10:53:00', '10:54:00', '10:55:00', '10:56:00', '10:57:00', '10:58:00', '10:59:00', '11:00:00',
      '11:01:00', '11:02:00', '11:03:00', '11:04:00', '11:05:00', '11:06:00', '11:07:00', '11:08:00', '11:09:00', '11:10:00',
      '11:11:00', '11:12:00', '11:13:00', '11:14:00', '11:15:00', '11:16:00', '11:17:00', '11:18:00', '11:19:00', '11:20:00',
      '11:21:00', '11:22:00', '11:23:00', '11:24:00', '11:25:00', '11:26:00', '11:27:00', '11:28:00', '11:29:00',

      # '13:30:00',
      '13:31:00', '13:32:00', '13:33:00', '13:34:00', '13:35:00', '13:36:00', '13:37:00', '13:38:00', '13:39:00', '13:40:00',
      '13:41:00', '13:42:00', '13:43:00', '13:44:00', '13:45:00', '13:46:00', '13:47:00', '13:48:00', '13:49:00', '13:50:00',
      '13:51:00', '13:52:00', '13:53:00', '13:54:00', '13:55:00', '13:56:00', '13:57:00', '13:58:00', '13:59:00', '14:00:00',
      '14:01:00', '14:02:00', '14:03:00', '14:04:00', '14:05:00', '14:06:00', '14:07:00', '14:08:00', '14:09:00', '14:10:00',
      '14:11:00', '14:12:00', '14:13:00', '14:14:00', '14:15:00', '14:16:00', '14:17:00', '14:18:00', '14:19:00', '14:20:00',
      '14:21:00', '14:22:00', '14:23:00', '14:24:00', '14:25:00', '14:26:00', '14:27:00', '14:28:00', '14:29:00', '14:30:00',
      '14:31:00', '14:32:00', '14:33:00', '14:34:00', '14:35:00', '14:36:00', '14:37:00', '14:38:00', '14:39:00', '14:40:00',
      '14:41:00', '14:42:00', '14:43:00', '14:44:00', '14:45:00', '14:46:00', '14:47:00', '14:48:00', '14:49:00', '14:50:00',
      '14:51:00', '14:52:00', '14:53:00', '14:54:00', '14:55:00', '14:56:00', '14:57:00', '14:58:00', '14:59:00',
     ]




freq_5m = \
     [
      # '21:00:00',
      '21:05:00', '21:10:00', '21:15:00', '21:20:00', '21:25:00', '21:30:00', '21:35:00', '21:40:00', '21:45:00', '21:50:00', '21:55:00', '22:00:00',
      '22:05:00', '22:10:00', '22:15:00', '22:20:00', '22:25:00', '22:30:00', '22:35:00', '22:40:00', '22:45:00', '22:50:00', '22:55:00', '23:00:00',
      '23:05:00', '23:10:00', '23:15:00', '23:20:00', '23:25:00', '23:30:00', '23:35:00', '23:40:00', '23:45:00', '23:50:00', '23:55:00', '00:00:00',

      '00:05:00', '00:10:00', '00:15:00', '00:20:00', '00:25:00', '00:30:00', '00:35:00', '00:40:00', '00:45:00', '00:50:00', '00:55:00', '01:00:00',
      '01:05:00', '01:10:00', '01:15:00', '01:20:00', '01:25:00', '01:30:00', '01:35:00', '01:40:00', '01:45:00', '01:50:00', '01:55:00', '02:00:00',

      # '09:00:00',
      '09:05:00', '09:06:00', '09:07:00', '09:08:00', '09:09:00', '09:10:00',
      '09:11:00', '09:12:00', '09:13:00', '09:14:00', '09:15:00', '09:16:00', '09:17:00', '09:18:00', '09:19:00', '09:20:00',
      '09:21:00', '09:22:00', '09:23:00', '09:24:00', '09:25:00', '09:26:00', '09:27:00', '09:28:00', '09:29:00', '09:30:00',
      '09:31:00', '09:32:00', '09:33:00', '09:34:00', '09:35:00', '09:36:00', '09:37:00', '09:38:00', '09:39:00', '09:40:00',
      '09:41:00', '09:42:00', '09:43:00', '09:44:00', '09:45:00', '09:46:00', '09:47:00', '09:48:00', '09:49:00', '09:50:00',
      '09:51:00', '09:52:00', '09:53:00', '09:54:00', '09:55:00', '09:56:00', '09:57:00', '09:58:00', '09:59:00', '10:00:00',
      '10:01:00', '10:02:00', '10:03:00', '10:04:00', '10:05:00', '10:06:00', '10:07:00', '10:08:00', '10:09:00', '10:10:00',
      '10:11:00', '10:12:00', '10:13:00', '10:14:00', '10:15:00',
      # '10:30:00',
      '10:31:00', '10:32:00', '10:33:00', '10:34:00', '10:35:00', '10:36:00', '10:37:00', '10:38:00', '10:39:00', '10:40:00',
      '10:41:00', '10:42:00', '10:43:00', '10:44:00', '10:45:00', '10:46:00', '10:47:00', '10:48:00', '10:49:00', '10:50:00',
      '10:51:00', '10:52:00', '10:53:00', '10:54:00', '10:55:00', '10:56:00', '10:57:00', '10:58:00', '10:59:00', '11:00:00',
      '11:01:00', '11:02:00', '11:03:00', '11:04:00', '11:05:00', '11:06:00', '11:07:00', '11:08:00', '11:09:00', '11:10:00',
      '11:11:00', '11:12:00', '11:13:00', '11:14:00', '11:15:00', '11:16:00', '11:17:00', '11:18:00', '11:19:00', '11:20:00',
      '11:21:00', '11:22:00', '11:23:00', '11:24:00', '11:25:00', '11:26:00', '11:27:00', '11:28:00', '11:29:00', '11:30:00',

      # '13:30:00',
      '13:31:00', '13:32:00', '13:33:00', '13:34:00', '13:35:00', '13:36:00', '13:37:00', '13:38:00', '13:39:00', '13:40:00',
      '13:41:00', '13:42:00', '13:43:00', '13:44:00', '13:45:00', '13:46:00', '13:47:00', '13:48:00', '13:49:00', '13:50:00',
      '13:51:00', '13:52:00', '13:53:00', '13:54:00', '13:55:00', '13:56:00', '13:57:00', '13:58:00', '13:59:00', '14:00:00',
      '14:01:00', '14:02:00', '14:03:00', '14:04:00', '14:05:00', '14:06:00', '14:07:00', '14:08:00', '14:09:00', '14:10:00',
      '14:11:00', '14:12:00', '14:13:00', '14:14:00', '14:15:00', '14:16:00', '14:17:00', '14:18:00', '14:19:00', '14:20:00',
      '14:21:00', '14:22:00', '14:23:00', '14:24:00', '14:25:00', '14:26:00', '14:27:00', '14:28:00', '14:29:00', '14:30:00',
      '14:31:00', '14:32:00', '14:33:00', '14:34:00', '14:35:00', '14:36:00', '14:37:00', '14:38:00', '14:39:00', '14:40:00',
      '14:41:00', '14:42:00', '14:43:00', '14:44:00', '14:45:00', '14:46:00', '14:47:00', '14:48:00', '14:49:00', '14:50:00',
      '14:51:00', '14:52:00', '14:53:00', '14:54:00', '14:55:00', '14:56:00', '14:57:00', '14:58:00', '14:59:00',
     ]









freq_10s_sim = \
 [
  '21:00:00', '21:00:10', '21:00:20', '21:00:30', '21:00:40', '21:00:50',
  '21:01:00', '21:01:10', '21:01:20', '21:01:30', '21:01:40', '21:01:50',
  '21:02:00', '21:02:10', '21:02:20', '21:02:30', '21:02:40', '21:02:50',
  '21:03:00', '21:03:10', '21:03:20', '21:03:30', '21:03:40', '21:03:50',
  '21:04:00', '21:04:10', '21:04:20', '21:04:30', '21:04:40', '21:04:50',
  '21:05:00', '21:05:10', '21:05:20', '21:05:30', '21:05:40', '21:05:50',
  '21:06:00', '21:06:10', '21:06:20', '21:06:30', '21:06:40', '21:06:50',
  '21:07:00', '21:07:10', '21:07:20', '21:07:30', '21:07:40', '21:07:50',
  '21:08:00', '21:08:10', '21:08:20', '21:08:30', '21:08:40', '21:08:50',
  '21:09:00', '21:09:10', '21:09:20', '21:09:30', '21:09:40', '21:09:50',
  '21:10:00', '21:10:10', '21:10:20', '21:10:30', '21:10:40', '21:10:50',
  '21:11:00', '21:11:10', '21:11:20', '21:11:30', '21:11:40', '21:11:50',
  '21:12:00', '21:12:10', '21:12:20', '21:12:30', '21:12:40', '21:12:50',
  '21:13:00', '21:13:10', '21:13:20', '21:13:30', '21:13:40', '21:13:50',
  '21:14:00', '21:14:10', '21:14:20', '21:14:30', '21:14:40', '21:14:50',
  '21:15:00', '21:15:10', '21:15:20', '21:15:30', '21:15:40', '21:15:50',
  '21:16:00', '21:16:10', '21:16:20', '21:16:30', '21:16:40', '21:16:50',
  '21:17:00', '21:17:10', '21:17:20', '21:17:30', '21:17:40', '21:17:50',
  '21:18:00', '21:18:10', '21:18:20', '21:18:30', '21:18:40', '21:18:50',
  '21:19:00', '21:19:10', '21:19:20', '21:19:30', '21:19:40', '21:19:50',
  '21:20:00', '21:20:10', '21:20:20', '21:20:30', '21:20:40', '21:20:50',
  '21:21:00', '21:21:10', '21:21:20', '21:21:30', '21:21:40', '21:21:50',
  '21:22:00', '21:22:10', '21:22:20', '21:22:30', '21:22:40', '21:22:50',
  '21:23:00', '21:23:10', '21:23:20', '21:23:30', '21:23:40', '21:23:50',
  '21:24:00', '21:24:10', '21:24:20', '21:24:30', '21:24:40', '21:24:50',
  '21:25:00', '21:25:10', '21:25:20', '21:25:30', '21:25:40', '21:25:50',
  '21:26:00', '21:26:10', '21:26:20', '21:26:30', '21:26:40', '21:26:50',
  '21:27:00', '21:27:10', '21:27:20', '21:27:30', '21:27:40', '21:27:50',
  '21:28:00', '21:28:10', '21:28:20', '21:28:30', '21:28:40', '21:28:50',
  '21:29:00', '21:29:10', '21:29:20', '21:29:30', '21:29:40', '21:29:50',
  '21:30:00', '21:30:10', '21:30:20', '21:30:30', '21:30:40', '21:30:50',
  '21:31:00', '21:31:10', '21:31:20', '21:31:30', '21:31:40', '21:31:50',
  '21:32:00', '21:32:10', '21:32:20', '21:32:30', '21:32:40', '21:32:50',
  '21:33:00', '21:33:10', '21:33:20', '21:33:30', '21:33:40', '21:33:50',
  '21:34:00', '21:34:10', '21:34:20', '21:34:30', '21:34:40', '21:34:50',
  '21:35:00', '21:35:10', '21:35:20', '21:35:30', '21:35:40', '21:35:50',
  '21:36:00', '21:36:10', '21:36:20', '21:36:30', '21:36:40', '21:36:50',
  '21:37:00', '21:37:10', '21:37:20', '21:37:30', '21:37:40', '21:37:50',
  '21:38:00', '21:38:10', '21:38:20', '21:38:30', '21:38:40', '21:38:50',
  '21:39:00', '21:39:10', '21:39:20', '21:39:30', '21:39:40', '21:39:50',
  '21:40:00', '21:40:10', '21:40:20', '21:40:30', '21:40:40', '21:40:50',
  '21:41:00', '21:41:10', '21:41:20', '21:41:30', '21:41:40', '21:41:50',
  '21:42:00', '21:42:10', '21:42:20', '21:42:30', '21:42:40', '21:42:50',
  '21:43:00', '21:43:10', '21:43:20', '21:43:30', '21:43:40', '21:43:50',
  '21:44:00', '21:44:10', '21:44:20', '21:44:30', '21:44:40', '21:44:50',
  '21:45:00', '21:45:10', '21:45:20', '21:45:30', '21:45:40', '21:45:50',
  '21:46:00', '21:46:10', '21:46:20', '21:46:30', '21:46:40', '21:46:50',
  '21:47:00', '21:47:10', '21:47:20', '21:47:30', '21:47:40', '21:47:50',
  '21:48:00', '21:48:10', '21:48:20', '21:48:30', '21:48:40', '21:48:50',
  '21:49:00', '21:49:10', '21:49:20', '21:49:30', '21:49:40', '21:49:50',
  '21:50:00', '21:50:10', '21:50:20', '21:50:30', '21:50:40', '21:50:50',
  '21:51:00', '21:51:10', '21:51:20', '21:51:30', '21:51:40', '21:51:50',
  '21:52:00', '21:52:10', '21:52:20', '21:52:30', '21:52:40', '21:52:50',
  '21:53:00', '21:53:10', '21:53:20', '21:53:30', '21:53:40', '21:53:50',
  '21:54:00', '21:54:10', '21:54:20', '21:54:30', '21:54:40', '21:54:50',
  '21:55:00', '21:55:10', '21:55:20', '21:55:30', '21:55:40', '21:55:50',
  '21:56:00', '21:56:10', '21:56:20', '21:56:30', '21:56:40', '21:56:50',
  '21:57:00', '21:57:10', '21:57:20', '21:57:30', '21:57:40', '21:57:50',
  '21:58:00', '21:58:10', '21:58:20', '21:58:30', '21:58:40', '21:58:50',
  '21:59:00', '21:59:10', '21:59:20', '21:59:30', '21:59:40', '21:59:50',
  '22:00:00', '22:00:10', '22:00:20', '22:00:30', '22:00:40', '22:00:50',
  '22:01:00', '22:01:10', '22:01:20', '22:01:30', '22:01:40', '22:01:50',
  '22:02:00', '22:02:10', '22:02:20', '22:02:30', '22:02:40', '22:02:50',
  '22:03:00', '22:03:10', '22:03:20', '22:03:30', '22:03:40', '22:03:50',
  '22:04:00', '22:04:10', '22:04:20', '22:04:30', '22:04:40', '22:04:50',
  '22:05:00', '22:05:10', '22:05:20', '22:05:30', '22:05:40', '22:05:50',
  '22:06:00', '22:06:10', '22:06:20', '22:06:30', '22:06:40', '22:06:50',
  '22:07:00', '22:07:10', '22:07:20', '22:07:30', '22:07:40', '22:07:50',
  '22:08:00', '22:08:10', '22:08:20', '22:08:30', '22:08:40', '22:08:50',
  '22:09:00', '22:09:10', '22:09:20', '22:09:30', '22:09:40', '22:09:50',
  '22:10:00', '22:10:10', '22:10:20', '22:10:30', '22:10:40', '22:10:50',
  '22:11:00', '22:11:10', '22:11:20', '22:11:30', '22:11:40', '22:11:50',
  '22:12:00', '22:12:10', '22:12:20', '22:12:30', '22:12:40', '22:12:50',
  '22:13:00', '22:13:10', '22:13:20', '22:13:30', '22:13:40', '22:13:50',
  '22:14:00', '22:14:10', '22:14:20', '22:14:30', '22:14:40', '22:14:50',
  '22:15:00', '22:15:10', '22:15:20', '22:15:30', '22:15:40', '22:15:50',
  '22:16:00', '22:16:10', '22:16:20', '22:16:30', '22:16:40', '22:16:50',
  '22:17:00', '22:17:10', '22:17:20', '22:17:30', '22:17:40', '22:17:50',
  '22:18:00', '22:18:10', '22:18:20', '22:18:30', '22:18:40', '22:18:50',
  '22:19:00', '22:19:10', '22:19:20', '22:19:30', '22:19:40', '22:19:50',
  '22:20:00', '22:20:10', '22:20:20', '22:20:30', '22:20:40', '22:20:50',
  '22:21:00', '22:21:10', '22:21:20', '22:21:30', '22:21:40', '22:21:50',
  '22:22:00', '22:22:10', '22:22:20', '22:22:30', '22:22:40', '22:22:50',
  '22:23:00', '22:23:10', '22:23:20', '22:23:30', '22:23:40', '22:23:50',
  '22:24:00', '22:24:10', '22:24:20', '22:24:30', '22:24:40', '22:24:50',
  '22:25:00', '22:25:10', '22:25:20', '22:25:30', '22:25:40', '22:25:50',
  '22:26:00', '22:26:10', '22:26:20', '22:26:30', '22:26:40', '22:26:50',
  '22:27:00', '22:27:10', '22:27:20', '22:27:30', '22:27:40', '22:27:50',
  '22:28:00', '22:28:10', '22:28:20', '22:28:30', '22:28:40', '22:28:50',
  '22:29:00', '22:29:10', '22:29:20', '22:29:30', '22:29:40', '22:29:50',
  '22:30:00', '22:30:10', '22:30:20', '22:30:30', '22:30:40', '22:30:50',
  '22:31:00', '22:31:10', '22:31:20', '22:31:30', '22:31:40', '22:31:50',
  '22:32:00', '22:32:10', '22:32:20', '22:32:30', '22:32:40', '22:32:50',
  '22:33:00', '22:33:10', '22:33:20', '22:33:30', '22:33:40', '22:33:50',
  '22:34:00', '22:34:10', '22:34:20', '22:34:30', '22:34:40', '22:34:50',
  '22:35:00', '22:35:10', '22:35:20', '22:35:30', '22:35:40', '22:35:50',
  '22:36:00', '22:36:10', '22:36:20', '22:36:30', '22:36:40', '22:36:50',
  '22:37:00', '22:37:10', '22:37:20', '22:37:30', '22:37:40', '22:37:50',
  '22:38:00', '22:38:10', '22:38:20', '22:38:30', '22:38:40', '22:38:50',
  '22:39:00', '22:39:10', '22:39:20', '22:39:30', '22:39:40', '22:39:50',
  '22:40:00', '22:40:10', '22:40:20', '22:40:30', '22:40:40', '22:40:50',
  '22:41:00', '22:41:10', '22:41:20', '22:41:30', '22:41:40', '22:41:50',
  '22:42:00', '22:42:10', '22:42:20', '22:42:30', '22:42:40', '22:42:50',
  '22:43:00', '22:43:10', '22:43:20', '22:43:30', '22:43:40', '22:43:50',
  '22:44:00', '22:44:10', '22:44:20', '22:44:30', '22:44:40', '22:44:50',
  '22:45:00', '22:45:10', '22:45:20', '22:45:30', '22:45:40', '22:45:50',
  '22:46:00', '22:46:10', '22:46:20', '22:46:30', '22:46:40', '22:46:50',
  '22:47:00', '22:47:10', '22:47:20', '22:47:30', '22:47:40', '22:47:50',
  '22:48:00', '22:48:10', '22:48:20', '22:48:30', '22:48:40', '22:48:50',
  '22:49:00', '22:49:10', '22:49:20', '22:49:30', '22:49:40', '22:49:50',
  '22:50:00', '22:50:10', '22:50:20', '22:50:30', '22:50:40', '22:50:50',
  '22:51:00', '22:51:10', '22:51:20', '22:51:30', '22:51:40', '22:51:50',
  '22:52:00', '22:52:10', '22:52:20', '22:52:30', '22:52:40', '22:52:50',
  '22:53:00', '22:53:10', '22:53:20', '22:53:30', '22:53:40', '22:53:50',
  '22:54:00', '22:54:10', '22:54:20', '22:54:30', '22:54:40', '22:54:50',
  '22:55:00', '22:55:10', '22:55:20', '22:55:30', '22:55:40', '22:55:50',
  '22:56:00', '22:56:10', '22:56:20', '22:56:30', '22:56:40', '22:56:50',
  '22:57:00', '22:57:10', '22:57:20', '22:57:30', '22:57:40', '22:57:50',
  '22:58:00', '22:58:10', '22:58:20', '22:58:30', '22:58:40', '22:58:50',
  '22:59:00', '22:59:10', '22:59:20', '22:59:30', '22:59:40', '22:59:50',
  '23:00:00', '23:00:10', '23:00:20', '23:00:30', '23:00:40', '23:00:50',
  '23:01:00', '23:01:10', '23:01:20', '23:01:30', '23:01:40', '23:01:50',
  '23:02:00', '23:02:10', '23:02:20', '23:02:30', '23:02:40', '23:02:50',
  '23:03:00', '23:03:10', '23:03:20', '23:03:30', '23:03:40', '23:03:50',
  '23:04:00', '23:04:10', '23:04:20', '23:04:30', '23:04:40', '23:04:50',
  '23:05:00', '23:05:10', '23:05:20', '23:05:30', '23:05:40', '23:05:50',
  '23:06:00', '23:06:10', '23:06:20', '23:06:30', '23:06:40', '23:06:50',
  '23:07:00', '23:07:10', '23:07:20', '23:07:30', '23:07:40', '23:07:50',
  '23:08:00', '23:08:10', '23:08:20', '23:08:30', '23:08:40', '23:08:50',
  '23:09:00', '23:09:10', '23:09:20', '23:09:30', '23:09:40', '23:09:50',
  '23:10:00', '23:10:10', '23:10:20', '23:10:30', '23:10:40', '23:10:50',
  '23:11:00', '23:11:10', '23:11:20', '23:11:30', '23:11:40', '23:11:50',
  '23:12:00', '23:12:10', '23:12:20', '23:12:30', '23:12:40', '23:12:50',
  '23:13:00', '23:13:10', '23:13:20', '23:13:30', '23:13:40', '23:13:50',
  '23:14:00', '23:14:10', '23:14:20', '23:14:30', '23:14:40', '23:14:50',
  '23:15:00', '23:15:10', '23:15:20', '23:15:30', '23:15:40', '23:15:50',
  '23:16:00', '23:16:10', '23:16:20', '23:16:30', '23:16:40', '23:16:50',
  '23:17:00', '23:17:10', '23:17:20', '23:17:30', '23:17:40', '23:17:50',
  '23:18:00', '23:18:10', '23:18:20', '23:18:30', '23:18:40', '23:18:50',
  '23:19:00', '23:19:10', '23:19:20', '23:19:30', '23:19:40', '23:19:50',
  '23:20:00', '23:20:10', '23:20:20', '23:20:30', '23:20:40', '23:20:50',
  '23:21:00', '23:21:10', '23:21:20', '23:21:30', '23:21:40', '23:21:50',
  '23:22:00', '23:22:10', '23:22:20', '23:22:30', '23:22:40', '23:22:50',
  '23:23:00', '23:23:10', '23:23:20', '23:23:30', '23:23:40', '23:23:50',
  '23:24:00', '23:24:10', '23:24:20', '23:24:30', '23:24:40', '23:24:50',
  '23:25:00', '23:25:10', '23:25:20', '23:25:30', '23:25:40', '23:25:50',
  '23:26:00', '23:26:10', '23:26:20', '23:26:30', '23:26:40', '23:26:50',
  '23:27:00', '23:27:10', '23:27:20', '23:27:30', '23:27:40', '23:27:50',
  '23:28:00', '23:28:10', '23:28:20', '23:28:30', '23:28:40', '23:28:50',
  '23:29:00', '23:29:10', '23:29:20', '23:29:30', '23:29:40', '23:29:50',
  '23:30:00', '23:30:10', '23:30:20', '23:30:30', '23:30:40', '23:30:50',
  '23:31:00', '23:31:10', '23:31:20', '23:31:30', '23:31:40', '23:31:50',
  '23:32:00', '23:32:10', '23:32:20', '23:32:30', '23:32:40', '23:32:50',
  '23:33:00', '23:33:10', '23:33:20', '23:33:30', '23:33:40', '23:33:50',
  '23:34:00', '23:34:10', '23:34:20', '23:34:30', '23:34:40', '23:34:50',
  '23:35:00', '23:35:10', '23:35:20', '23:35:30', '23:35:40', '23:35:50',
  '23:36:00', '23:36:10', '23:36:20', '23:36:30', '23:36:40', '23:36:50',
  '23:37:00', '23:37:10', '23:37:20', '23:37:30', '23:37:40', '23:37:50',
  '23:38:00', '23:38:10', '23:38:20', '23:38:30', '23:38:40', '23:38:50',
  '23:39:00', '23:39:10', '23:39:20', '23:39:30', '23:39:40', '23:39:50',
  '23:40:00', '23:40:10', '23:40:20', '23:40:30', '23:40:40', '23:40:50',
  '23:41:00', '23:41:10', '23:41:20', '23:41:30', '23:41:40', '23:41:50',
  '23:42:00', '23:42:10', '23:42:20', '23:42:30', '23:42:40', '23:42:50',
  '23:43:00', '23:43:10', '23:43:20', '23:43:30', '23:43:40', '23:43:50',
  '23:44:00', '23:44:10', '23:44:20', '23:44:30', '23:44:40', '23:44:50',
  '23:45:00', '23:45:10', '23:45:20', '23:45:30', '23:45:40', '23:45:50',
  '23:46:00', '23:46:10', '23:46:20', '23:46:30', '23:46:40', '23:46:50',
  '23:47:00', '23:47:10', '23:47:20', '23:47:30', '23:47:40', '23:47:50',
  '23:48:00', '23:48:10', '23:48:20', '23:48:30', '23:48:40', '23:48:50',
  '23:49:00', '23:49:10', '23:49:20', '23:49:30', '23:49:40', '23:49:50',
  '23:50:00', '23:50:10', '23:50:20', '23:50:30', '23:50:40', '23:50:50',
  '23:51:00', '23:51:10', '23:51:20', '23:51:30', '23:51:40', '23:51:50',
  '23:52:00', '23:52:10', '23:52:20', '23:52:30', '23:52:40', '23:52:50',
  '23:53:00', '23:53:10', '23:53:20', '23:53:30', '23:53:40', '23:53:50',
  '23:54:00', '23:54:10', '23:54:20', '23:54:30', '23:54:40', '23:54:50',
  '23:55:00', '23:55:10', '23:55:20', '23:55:30', '23:55:40', '23:55:50',
  '23:56:00', '23:56:10', '23:56:20', '23:56:30', '23:56:40', '23:56:50',
  '23:57:00', '23:57:10', '23:57:20', '23:57:30', '23:57:40', '23:57:50',
  '23:58:00', '23:58:10', '23:58:20', '23:58:30', '23:58:40', '23:58:50',
  '23:59:00', '23:59:10', '23:59:20', '23:59:30', '23:59:40', '23:59:50',
  '00:00:00', '00:00:10', '00:00:20', '00:00:30', '00:00:40', '00:00:50',
  '00:01:00', '00:01:10', '00:01:20', '00:01:30', '00:01:40', '00:01:50',
  '00:02:00', '00:02:10', '00:02:20', '00:02:30', '00:02:40', '00:02:50',
  '00:03:00', '00:03:10', '00:03:20', '00:03:30', '00:03:40', '00:03:50',
  '00:04:00', '00:04:10', '00:04:20', '00:04:30', '00:04:40', '00:04:50',
  '00:05:00', '00:05:10', '00:05:20', '00:05:30', '00:05:40', '00:05:50',
  '00:06:00', '00:06:10', '00:06:20', '00:06:30', '00:06:40', '00:06:50',
  '00:07:00', '00:07:10', '00:07:20', '00:07:30', '00:07:40', '00:07:50',
  '00:08:00', '00:08:10', '00:08:20', '00:08:30', '00:08:40', '00:08:50',
  '00:09:00', '00:09:10', '00:09:20', '00:09:30', '00:09:40', '00:09:50',
  '00:10:00', '00:10:10', '00:10:20', '00:10:30', '00:10:40', '00:10:50',
  '00:11:00', '00:11:10', '00:11:20', '00:11:30', '00:11:40', '00:11:50',
  '00:12:00', '00:12:10', '00:12:20', '00:12:30', '00:12:40', '00:12:50',
  '00:13:00', '00:13:10', '00:13:20', '00:13:30', '00:13:40', '00:13:50',
  '00:14:00', '00:14:10', '00:14:20', '00:14:30', '00:14:40', '00:14:50',
  '00:15:00', '00:15:10', '00:15:20', '00:15:30', '00:15:40', '00:15:50',
  '00:16:00', '00:16:10', '00:16:20', '00:16:30', '00:16:40', '00:16:50',
  '00:17:00', '00:17:10', '00:17:20', '00:17:30', '00:17:40', '00:17:50',
  '00:18:00', '00:18:10', '00:18:20', '00:18:30', '00:18:40', '00:18:50',
  '00:19:00', '00:19:10', '00:19:20', '00:19:30', '00:19:40', '00:19:50',
  '00:20:00', '00:20:10', '00:20:20', '00:20:30', '00:20:40', '00:20:50',
  '00:21:00', '00:21:10', '00:21:20', '00:21:30', '00:21:40', '00:21:50',
  '00:22:00', '00:22:10', '00:22:20', '00:22:30', '00:22:40', '00:22:50',
  '00:23:00', '00:23:10', '00:23:20', '00:23:30', '00:23:40', '00:23:50',
  '00:24:00', '00:24:10', '00:24:20', '00:24:30', '00:24:40', '00:24:50',
  '00:25:00', '00:25:10', '00:25:20', '00:25:30', '00:25:40', '00:25:50',
  '00:26:00', '00:26:10', '00:26:20', '00:26:30', '00:26:40', '00:26:50',
  '00:27:00', '00:27:10', '00:27:20', '00:27:30', '00:27:40', '00:27:50',
  '00:28:00', '00:28:10', '00:28:20', '00:28:30', '00:28:40', '00:28:50',
  '00:29:00', '00:29:10', '00:29:20', '00:29:30', '00:29:40', '00:29:50',
  '00:30:00', '00:30:10', '00:30:20', '00:30:30', '00:30:40', '00:30:50',
  '00:31:00', '00:31:10', '00:31:20', '00:31:30', '00:31:40', '00:31:50',
  '00:32:00', '00:32:10', '00:32:20', '00:32:30', '00:32:40', '00:32:50',
  '00:33:00', '00:33:10', '00:33:20', '00:33:30', '00:33:40', '00:33:50',
  '00:34:00', '00:34:10', '00:34:20', '00:34:30', '00:34:40', '00:34:50',
  '00:35:00', '00:35:10', '00:35:20', '00:35:30', '00:35:40', '00:35:50',
  '00:36:00', '00:36:10', '00:36:20', '00:36:30', '00:36:40', '00:36:50',
  '00:37:00', '00:37:10', '00:37:20', '00:37:30', '00:37:40', '00:37:50',
  '00:38:00', '00:38:10', '00:38:20', '00:38:30', '00:38:40', '00:38:50',
  '00:39:00', '00:39:10', '00:39:20', '00:39:30', '00:39:40', '00:39:50',
  '00:40:00', '00:40:10', '00:40:20', '00:40:30', '00:40:40', '00:40:50',
  '00:41:00', '00:41:10', '00:41:20', '00:41:30', '00:41:40', '00:41:50',
  '00:42:00', '00:42:10', '00:42:20', '00:42:30', '00:42:40', '00:42:50',
  '00:43:00', '00:43:10', '00:43:20', '00:43:30', '00:43:40', '00:43:50',
  '00:44:00', '00:44:10', '00:44:20', '00:44:30', '00:44:40', '00:44:50',
  '00:45:00', '00:45:10', '00:45:20', '00:45:30', '00:45:40', '00:45:50',
  '00:46:00', '00:46:10', '00:46:20', '00:46:30', '00:46:40', '00:46:50',
  '00:47:00', '00:47:10', '00:47:20', '00:47:30', '00:47:40', '00:47:50',
  '00:48:00', '00:48:10', '00:48:20', '00:48:30', '00:48:40', '00:48:50',
  '00:49:00', '00:49:10', '00:49:20', '00:49:30', '00:49:40', '00:49:50',
  '00:50:00', '00:50:10', '00:50:20', '00:50:30', '00:50:40', '00:50:50',
  '00:51:00', '00:51:10', '00:51:20', '00:51:30', '00:51:40', '00:51:50',
  '00:52:00', '00:52:10', '00:52:20', '00:52:30', '00:52:40', '00:52:50',
  '00:53:00', '00:53:10', '00:53:20', '00:53:30', '00:53:40', '00:53:50',
  '00:54:00', '00:54:10', '00:54:20', '00:54:30', '00:54:40', '00:54:50',
  '00:55:00', '00:55:10', '00:55:20', '00:55:30', '00:55:40', '00:55:50',
  '00:56:00', '00:56:10', '00:56:20', '00:56:30', '00:56:40', '00:56:50',
  '00:57:00', '00:57:10', '00:57:20', '00:57:30', '00:57:40', '00:57:50',
  '00:58:00', '00:58:10', '00:58:20', '00:58:30', '00:58:40', '00:58:50',
  '00:59:00', '00:59:10', '00:59:20', '00:59:30', '00:59:40', '00:59:50',
  '01:00:00', '01:00:10', '01:00:20', '01:00:30', '01:00:40', '01:00:50',
  '01:01:00', '01:01:10', '01:01:20', '01:01:30', '01:01:40', '01:01:50',
  '01:02:00', '01:02:10', '01:02:20', '01:02:30', '01:02:40', '01:02:50',
  '01:03:00', '01:03:10', '01:03:20', '01:03:30', '01:03:40', '01:03:50',
  '01:04:00', '01:04:10', '01:04:20', '01:04:30', '01:04:40', '01:04:50',
  '01:05:00', '01:05:10', '01:05:20', '01:05:30', '01:05:40', '01:05:50',
  '01:06:00', '01:06:10', '01:06:20', '01:06:30', '01:06:40', '01:06:50',
  '01:07:00', '01:07:10', '01:07:20', '01:07:30', '01:07:40', '01:07:50',
  '01:08:00', '01:08:10', '01:08:20', '01:08:30', '01:08:40', '01:08:50',
  '01:09:00', '01:09:10', '01:09:20', '01:09:30', '01:09:40', '01:09:50',
  '01:10:00', '01:10:10', '01:10:20', '01:10:30', '01:10:40', '01:10:50',
  '01:11:00', '01:11:10', '01:11:20', '01:11:30', '01:11:40', '01:11:50',
  '01:12:00', '01:12:10', '01:12:20', '01:12:30', '01:12:40', '01:12:50',
  '01:13:00', '01:13:10', '01:13:20', '01:13:30', '01:13:40', '01:13:50',
  '01:14:00', '01:14:10', '01:14:20', '01:14:30', '01:14:40', '01:14:50',
  '01:15:00', '01:15:10', '01:15:20', '01:15:30', '01:15:40', '01:15:50',
  '01:16:00', '01:16:10', '01:16:20', '01:16:30', '01:16:40', '01:16:50',
  '01:17:00', '01:17:10', '01:17:20', '01:17:30', '01:17:40', '01:17:50',
  '01:18:00', '01:18:10', '01:18:20', '01:18:30', '01:18:40', '01:18:50',
  '01:19:00', '01:19:10', '01:19:20', '01:19:30', '01:19:40', '01:19:50',
  '01:20:00', '01:20:10', '01:20:20', '01:20:30', '01:20:40', '01:20:50',
  '01:21:00', '01:21:10', '01:21:20', '01:21:30', '01:21:40', '01:21:50',
  '01:22:00', '01:22:10', '01:22:20', '01:22:30', '01:22:40', '01:22:50',
  '01:23:00', '01:23:10', '01:23:20', '01:23:30', '01:23:40', '01:23:50',
  '01:24:00', '01:24:10', '01:24:20', '01:24:30', '01:24:40', '01:24:50',
  '01:25:00', '01:25:10', '01:25:20', '01:25:30', '01:25:40', '01:25:50',
  '01:26:00', '01:26:10', '01:26:20', '01:26:30', '01:26:40', '01:26:50',
  '01:27:00', '01:27:10', '01:27:20', '01:27:30', '01:27:40', '01:27:50',
  '01:28:00', '01:28:10', '01:28:20', '01:28:30', '01:28:40', '01:28:50',
  '01:29:00', '01:29:10', '01:29:20', '01:29:30', '01:29:40', '01:29:50',
  '01:30:00', '01:30:10', '01:30:20', '01:30:30', '01:30:40', '01:30:50',
  '01:31:00', '01:31:10', '01:31:20', '01:31:30', '01:31:40', '01:31:50',
  '01:32:00', '01:32:10', '01:32:20', '01:32:30', '01:32:40', '01:32:50',
  '01:33:00', '01:33:10', '01:33:20', '01:33:30', '01:33:40', '01:33:50',
  '01:34:00', '01:34:10', '01:34:20', '01:34:30', '01:34:40', '01:34:50',
  '01:35:00', '01:35:10', '01:35:20', '01:35:30', '01:35:40', '01:35:50',
  '01:36:00', '01:36:10', '01:36:20', '01:36:30', '01:36:40', '01:36:50',
  '01:37:00', '01:37:10', '01:37:20', '01:37:30', '01:37:40', '01:37:50',
  '01:38:00', '01:38:10', '01:38:20', '01:38:30', '01:38:40', '01:38:50',
  '01:39:00', '01:39:10', '01:39:20', '01:39:30', '01:39:40', '01:39:50',
  '01:40:00', '01:40:10', '01:40:20', '01:40:30', '01:40:40', '01:40:50',
  '01:41:00', '01:41:10', '01:41:20', '01:41:30', '01:41:40', '01:41:50',
  '01:42:00', '01:42:10', '01:42:20', '01:42:30', '01:42:40', '01:42:50',
  '01:43:00', '01:43:10', '01:43:20', '01:43:30', '01:43:40', '01:43:50',
  '01:44:00', '01:44:10', '01:44:20', '01:44:30', '01:44:40', '01:44:50',
  '01:45:00', '01:45:10', '01:45:20', '01:45:30', '01:45:40', '01:45:50',
  '01:46:00', '01:46:10', '01:46:20', '01:46:30', '01:46:40', '01:46:50',
  '01:47:00', '01:47:10', '01:47:20', '01:47:30', '01:47:40', '01:47:50',
  '01:48:00', '01:48:10', '01:48:20', '01:48:30', '01:48:40', '01:48:50',
  '01:49:00', '01:49:10', '01:49:20', '01:49:30', '01:49:40', '01:49:50',
  '01:50:00', '01:50:10', '01:50:20', '01:50:30', '01:50:40', '01:50:50',
  '01:51:00', '01:51:10', '01:51:20', '01:51:30', '01:51:40', '01:51:50',
  '01:52:00', '01:52:10', '01:52:20', '01:52:30', '01:52:40', '01:52:50',
  '01:53:00', '01:53:10', '01:53:20', '01:53:30', '01:53:40', '01:53:50',
  '01:54:00', '01:54:10', '01:54:20', '01:54:30', '01:54:40', '01:54:50',
  '01:55:00', '01:55:10', '01:55:20', '01:55:30', '01:55:40', '01:55:50',
  '01:56:00', '01:56:10', '01:56:20', '01:56:30', '01:56:40', '01:56:50',
  '01:57:00', '01:57:10', '01:57:20', '01:57:30', '01:57:40', '01:57:50',
  '01:58:00', '01:58:10', '01:58:20', '01:58:30', '01:58:40', '01:58:50',
  '01:59:00', '01:59:10', '01:59:20', '01:59:30', '01:59:40', '01:59:50',
  '02:00:00', '02:00:10', '02:00:20', '02:00:30', '02:00:40', '02:00:50',
  '02:01:00', '02:01:10', '02:01:20', '02:01:30', '02:01:40', '02:01:50',
  '02:02:00', '02:02:10', '02:02:20', '02:02:30', '02:02:40', '02:02:50',
  '02:03:00', '02:03:10', '02:03:20', '02:03:30', '02:03:40', '02:03:50',
  '02:04:00', '02:04:10', '02:04:20', '02:04:30', '02:04:40', '02:04:50',
  '02:05:00', '02:05:10', '02:05:20', '02:05:30', '02:05:40', '02:05:50',
  '02:06:00', '02:06:10', '02:06:20', '02:06:30', '02:06:40', '02:06:50',
  '02:07:00', '02:07:10', '02:07:20', '02:07:30', '02:07:40', '02:07:50',
  '02:08:00', '02:08:10', '02:08:20', '02:08:30', '02:08:40', '02:08:50',
  '02:09:00', '02:09:10', '02:09:20', '02:09:30', '02:09:40', '02:09:50',
  '02:10:00', '02:10:10', '02:10:20', '02:10:30', '02:10:40', '02:10:50',
  '02:11:00', '02:11:10', '02:11:20', '02:11:30', '02:11:40', '02:11:50',
  '02:12:00', '02:12:10', '02:12:20', '02:12:30', '02:12:40', '02:12:50',
  '02:13:00', '02:13:10', '02:13:20', '02:13:30', '02:13:40', '02:13:50',
  '02:14:00', '02:14:10', '02:14:20', '02:14:30', '02:14:40', '02:14:50',
  '02:15:00', '02:15:10', '02:15:20', '02:15:30', '02:15:40', '02:15:50',
  '02:16:00', '02:16:10', '02:16:20', '02:16:30', '02:16:40', '02:16:50',
  '02:17:00', '02:17:10', '02:17:20', '02:17:30', '02:17:40', '02:17:50',
  '02:18:00', '02:18:10', '02:18:20', '02:18:30', '02:18:40', '02:18:50',
  '02:19:00', '02:19:10', '02:19:20', '02:19:30', '02:19:40', '02:19:50',
  '02:20:00', '02:20:10', '02:20:20', '02:20:30', '02:20:40', '02:20:50',
  '02:21:00', '02:21:10', '02:21:20', '02:21:30', '02:21:40', '02:21:50',
  '02:22:00', '02:22:10', '02:22:20', '02:22:30', '02:22:40', '02:22:50',
  '02:23:00', '02:23:10', '02:23:20', '02:23:30', '02:23:40', '02:23:50',
  '02:24:00', '02:24:10', '02:24:20', '02:24:30', '02:24:40', '02:24:50',
  '02:25:00', '02:25:10', '02:25:20', '02:25:30', '02:25:40', '02:25:50',
  '02:26:00', '02:26:10', '02:26:20', '02:26:30', '02:26:40', '02:26:50',
  '02:27:00', '02:27:10', '02:27:20', '02:27:30', '02:27:40', '02:27:50',
  '02:28:00', '02:28:10', '02:28:20', '02:28:30', '02:28:40', '02:28:50',
  '02:29:00', '02:29:10', '02:29:20', '02:29:30', '02:29:40', '02:29:50',

  '09:00:00', '09:00:10', '09:00:20', '09:00:30', '09:00:40', '09:00:50',
  '09:01:00', '09:01:10', '09:01:20', '09:01:30', '09:01:40', '09:01:50',
  '09:02:00', '09:02:10', '09:02:20', '09:02:30', '09:02:40', '09:02:50',
  '09:03:00', '09:03:10', '09:03:20', '09:03:30', '09:03:40', '09:03:50',
  '09:04:00', '09:04:10', '09:04:20', '09:04:30', '09:04:40', '09:04:50',
  '09:05:00', '09:05:10', '09:05:20', '09:05:30', '09:05:40', '09:05:50',
  '09:06:00', '09:06:10', '09:06:20', '09:06:30', '09:06:40', '09:06:50',
  '09:07:00', '09:07:10', '09:07:20', '09:07:30', '09:07:40', '09:07:50',
  '09:08:00', '09:08:10', '09:08:20', '09:08:30', '09:08:40', '09:08:50',
  '09:09:00', '09:09:10', '09:09:20', '09:09:30', '09:09:40', '09:09:50',
  '09:10:00', '09:10:10', '09:10:20', '09:10:30', '09:10:40', '09:10:50',
  '09:11:00', '09:11:10', '09:11:20', '09:11:30', '09:11:40', '09:11:50',
  '09:12:00', '09:12:10', '09:12:20', '09:12:30', '09:12:40', '09:12:50',
  '09:13:00', '09:13:10', '09:13:20', '09:13:30', '09:13:40', '09:13:50',
  '09:14:00', '09:14:10', '09:14:20', '09:14:30', '09:14:40', '09:14:50',
  '09:15:00', '09:15:10', '09:15:20', '09:15:30', '09:15:40', '09:15:50',
  '09:16:00', '09:16:10', '09:16:20', '09:16:30', '09:16:40', '09:16:50',
  '09:17:00', '09:17:10', '09:17:20', '09:17:30', '09:17:40', '09:17:50',
  '09:18:00', '09:18:10', '09:18:20', '09:18:30', '09:18:40', '09:18:50',
  '09:19:00', '09:19:10', '09:19:20', '09:19:30', '09:19:40', '09:19:50',
  '09:20:00', '09:20:10', '09:20:20', '09:20:30', '09:20:40', '09:20:50',
  '09:21:00', '09:21:10', '09:21:20', '09:21:30', '09:21:40', '09:21:50',
  '09:22:00', '09:22:10', '09:22:20', '09:22:30', '09:22:40', '09:22:50',
  '09:23:00', '09:23:10', '09:23:20', '09:23:30', '09:23:40', '09:23:50',
  '09:24:00', '09:24:10', '09:24:20', '09:24:30', '09:24:40', '09:24:50',
  '09:25:00', '09:25:10', '09:25:20', '09:25:30', '09:25:40', '09:25:50',
  '09:26:00', '09:26:10', '09:26:20', '09:26:30', '09:26:40', '09:26:50',
  '09:27:00', '09:27:10', '09:27:20', '09:27:30', '09:27:40', '09:27:50',
  '09:28:00', '09:28:10', '09:28:20', '09:28:30', '09:28:40', '09:28:50',
  '09:29:00', '09:29:10', '09:29:20', '09:29:30', '09:29:40', '09:29:50',
  '09:30:00', '09:30:10', '09:30:20', '09:30:30', '09:30:40', '09:30:50',
  '09:31:00', '09:31:10', '09:31:20', '09:31:30', '09:31:40', '09:31:50',
  '09:32:00', '09:32:10', '09:32:20', '09:32:30', '09:32:40', '09:32:50',
  '09:33:00', '09:33:10', '09:33:20', '09:33:30', '09:33:40', '09:33:50',
  '09:34:00', '09:34:10', '09:34:20', '09:34:30', '09:34:40', '09:34:50',
  '09:35:00', '09:35:10', '09:35:20', '09:35:30', '09:35:40', '09:35:50',
  '09:36:00', '09:36:10', '09:36:20', '09:36:30', '09:36:40', '09:36:50',
  '09:37:00', '09:37:10', '09:37:20', '09:37:30', '09:37:40', '09:37:50',
  '09:38:00', '09:38:10', '09:38:20', '09:38:30', '09:38:40', '09:38:50',
  '09:39:00', '09:39:10', '09:39:20', '09:39:30', '09:39:40', '09:39:50',
  '09:40:00', '09:40:10', '09:40:20', '09:40:30', '09:40:40', '09:40:50',
  '09:41:00', '09:41:10', '09:41:20', '09:41:30', '09:41:40', '09:41:50',
  '09:42:00', '09:42:10', '09:42:20', '09:42:30', '09:42:40', '09:42:50',
  '09:43:00', '09:43:10', '09:43:20', '09:43:30', '09:43:40', '09:43:50',
  '09:44:00', '09:44:10', '09:44:20', '09:44:30', '09:44:40', '09:44:50',
  '09:45:00', '09:45:10', '09:45:20', '09:45:30', '09:45:40', '09:45:50',
  '09:46:00', '09:46:10', '09:46:20', '09:46:30', '09:46:40', '09:46:50',
  '09:47:00', '09:47:10', '09:47:20', '09:47:30', '09:47:40', '09:47:50',
  '09:48:00', '09:48:10', '09:48:20', '09:48:30', '09:48:40', '09:48:50',
  '09:49:00', '09:49:10', '09:49:20', '09:49:30', '09:49:40', '09:49:50',
  '09:50:00', '09:50:10', '09:50:20', '09:50:30', '09:50:40', '09:50:50',
  '09:51:00', '09:51:10', '09:51:20', '09:51:30', '09:51:40', '09:51:50',
  '09:52:00', '09:52:10', '09:52:20', '09:52:30', '09:52:40', '09:52:50',
  '09:53:00', '09:53:10', '09:53:20', '09:53:30', '09:53:40', '09:53:50',
  '09:54:00', '09:54:10', '09:54:20', '09:54:30', '09:54:40', '09:54:50',
  '09:55:00', '09:55:10', '09:55:20', '09:55:30', '09:55:40', '09:55:50',
  '09:56:00', '09:56:10', '09:56:20', '09:56:30', '09:56:40', '09:56:50',
  '09:57:00', '09:57:10', '09:57:20', '09:57:30', '09:57:40', '09:57:50',
  '09:58:00', '09:58:10', '09:58:20', '09:58:30', '09:58:40', '09:58:50',
  '09:59:00', '09:59:10', '09:59:20', '09:59:30', '09:59:40', '09:59:50',
  '10:00:00', '10:00:10', '10:00:20', '10:00:30', '10:00:40', '10:00:50',
  '10:01:00', '10:01:10', '10:01:20', '10:01:30', '10:01:40', '10:01:50',
  '10:02:00', '10:02:10', '10:02:20', '10:02:30', '10:02:40', '10:02:50',
  '10:03:00', '10:03:10', '10:03:20', '10:03:30', '10:03:40', '10:03:50',
  '10:04:00', '10:04:10', '10:04:20', '10:04:30', '10:04:40', '10:04:50',
  '10:05:00', '10:05:10', '10:05:20', '10:05:30', '10:05:40', '10:05:50',
  '10:06:00', '10:06:10', '10:06:20', '10:06:30', '10:06:40', '10:06:50',
  '10:07:00', '10:07:10', '10:07:20', '10:07:30', '10:07:40', '10:07:50',
  '10:08:00', '10:08:10', '10:08:20', '10:08:30', '10:08:40', '10:08:50',
  '10:09:00', '10:09:10', '10:09:20', '10:09:30', '10:09:40', '10:09:50',
  '10:10:00', '10:10:10', '10:10:20', '10:10:30', '10:10:40', '10:10:50',
  '10:11:00', '10:11:10', '10:11:20', '10:11:30', '10:11:40', '10:11:50',
  '10:12:00', '10:12:10', '10:12:20', '10:12:30', '10:12:40', '10:12:50',
  '10:13:00', '10:13:10', '10:13:20', '10:13:30', '10:13:40', '10:13:50',
  '10:14:00', '10:14:10', '10:14:20', '10:14:30', '10:14:40', '10:14:50',

  '10:30:00', '10:30:10', '10:30:20', '10:30:30', '10:30:40', '10:30:50',
  '10:31:00', '10:31:10', '10:31:20', '10:31:30', '10:31:40', '10:31:50',
  '10:32:00', '10:32:10', '10:32:20', '10:32:30', '10:32:40', '10:32:50',
  '10:33:00', '10:33:10', '10:33:20', '10:33:30', '10:33:40', '10:33:50',
  '10:34:00', '10:34:10', '10:34:20', '10:34:30', '10:34:40', '10:34:50',
  '10:35:00', '10:35:10', '10:35:20', '10:35:30', '10:35:40', '10:35:50',
  '10:36:00', '10:36:10', '10:36:20', '10:36:30', '10:36:40', '10:36:50',
  '10:37:00', '10:37:10', '10:37:20', '10:37:30', '10:37:40', '10:37:50',
  '10:38:00', '10:38:10', '10:38:20', '10:38:30', '10:38:40', '10:38:50',
  '10:39:00', '10:39:10', '10:39:20', '10:39:30', '10:39:40', '10:39:50',
  '10:40:00', '10:40:10', '10:40:20', '10:40:30', '10:40:40', '10:40:50',
  '10:41:00', '10:41:10', '10:41:20', '10:41:30', '10:41:40', '10:41:50',
  '10:42:00', '10:42:10', '10:42:20', '10:42:30', '10:42:40', '10:42:50',
  '10:43:00', '10:43:10', '10:43:20', '10:43:30', '10:43:40', '10:43:50',
  '10:44:00', '10:44:10', '10:44:20', '10:44:30', '10:44:40', '10:44:50',
  '10:45:00', '10:45:10', '10:45:20', '10:45:30', '10:45:40', '10:45:50',
  '10:46:00', '10:46:10', '10:46:20', '10:46:30', '10:46:40', '10:46:50',
  '10:47:00', '10:47:10', '10:47:20', '10:47:30', '10:47:40', '10:47:50',
  '10:48:00', '10:48:10', '10:48:20', '10:48:30', '10:48:40', '10:48:50',
  '10:49:00', '10:49:10', '10:49:20', '10:49:30', '10:49:40', '10:49:50',
  '10:50:00', '10:50:10', '10:50:20', '10:50:30', '10:50:40', '10:50:50',
  '10:51:00', '10:51:10', '10:51:20', '10:51:30', '10:51:40', '10:51:50',
  '10:52:00', '10:52:10', '10:52:20', '10:52:30', '10:52:40', '10:52:50',
  '10:53:00', '10:53:10', '10:53:20', '10:53:30', '10:53:40', '10:53:50',
  '10:54:00', '10:54:10', '10:54:20', '10:54:30', '10:54:40', '10:54:50',
  '10:55:00', '10:55:10', '10:55:20', '10:55:30', '10:55:40', '10:55:50',
  '10:56:00', '10:56:10', '10:56:20', '10:56:30', '10:56:40', '10:56:50',
  '10:57:00', '10:57:10', '10:57:20', '10:57:30', '10:57:40', '10:57:50',
  '10:58:00', '10:58:10', '10:58:20', '10:58:30', '10:58:40', '10:58:50',
  '10:59:00', '10:59:10', '10:59:20', '10:59:30', '10:59:40', '10:59:50',
  '11:00:00', '11:00:10', '11:00:20', '11:00:30', '11:00:40', '11:00:50',
  '11:01:00', '11:01:10', '11:01:20', '11:01:30', '11:01:40', '11:01:50',
  '11:02:00', '11:02:10', '11:02:20', '11:02:30', '11:02:40', '11:02:50',
  '11:03:00', '11:03:10', '11:03:20', '11:03:30', '11:03:40', '11:03:50',
  '11:04:00', '11:04:10', '11:04:20', '11:04:30', '11:04:40', '11:04:50',
  '11:05:00', '11:05:10', '11:05:20', '11:05:30', '11:05:40', '11:05:50',
  '11:06:00', '11:06:10', '11:06:20', '11:06:30', '11:06:40', '11:06:50',
  '11:07:00', '11:07:10', '11:07:20', '11:07:30', '11:07:40', '11:07:50',
  '11:08:00', '11:08:10', '11:08:20', '11:08:30', '11:08:40', '11:08:50',
  '11:09:00', '11:09:10', '11:09:20', '11:09:30', '11:09:40', '11:09:50',
  '11:10:00', '11:10:10', '11:10:20', '11:10:30', '11:10:40', '11:10:50',
  '11:11:00', '11:11:10', '11:11:20', '11:11:30', '11:11:40', '11:11:50',
  '11:12:00', '11:12:10', '11:12:20', '11:12:30', '11:12:40', '11:12:50',
  '11:13:00', '11:13:10', '11:13:20', '11:13:30', '11:13:40', '11:13:50',
  '11:14:00', '11:14:10', '11:14:20', '11:14:30', '11:14:40', '11:14:50',
  '11:15:00', '11:15:10', '11:15:20', '11:15:30', '11:15:40', '11:15:50',
  '11:16:00', '11:16:10', '11:16:20', '11:16:30', '11:16:40', '11:16:50',
  '11:17:00', '11:17:10', '11:17:20', '11:17:30', '11:17:40', '11:17:50',
  '11:18:00', '11:18:10', '11:18:20', '11:18:30', '11:18:40', '11:18:50',
  '11:19:00', '11:19:10', '11:19:20', '11:19:30', '11:19:40', '11:19:50',
  '11:20:00', '11:20:10', '11:20:20', '11:20:30', '11:20:40', '11:20:50',
  '11:21:00', '11:21:10', '11:21:20', '11:21:30', '11:21:40', '11:21:50',
  '11:22:00', '11:22:10', '11:22:20', '11:22:30', '11:22:40', '11:22:50',
  '11:23:00', '11:23:10', '11:23:20', '11:23:30', '11:23:40', '11:23:50',
  '11:24:00', '11:24:10', '11:24:20', '11:24:30', '11:24:40', '11:24:50',
  '11:25:00', '11:25:10', '11:25:20', '11:25:30', '11:25:40', '11:25:50',
  '11:26:00', '11:26:10', '11:26:20', '11:26:30', '11:26:40', '11:26:50',
  '11:27:00', '11:27:10', '11:27:20', '11:27:30', '11:27:40', '11:27:50',
  '11:28:00', '11:28:10', '11:28:20', '11:28:30', '11:28:40', '11:28:50',
  '11:29:00', '11:29:10', '11:29:20', '11:29:30', '11:29:40', '11:29:50',

  '13:30:00', '13:30:10', '13:30:20', '13:30:30', '13:30:40', '13:30:50',
  '13:31:00', '13:31:10', '13:31:20', '13:31:30', '13:31:40', '13:31:50',
  '13:32:00', '13:32:10', '13:32:20', '13:32:30', '13:32:40', '13:32:50',
  '13:33:00', '13:33:10', '13:33:20', '13:33:30', '13:33:40', '13:33:50',
  '13:34:00', '13:34:10', '13:34:20', '13:34:30', '13:34:40', '13:34:50',
  '13:35:00', '13:35:10', '13:35:20', '13:35:30', '13:35:40', '13:35:50',
  '13:36:00', '13:36:10', '13:36:20', '13:36:30', '13:36:40', '13:36:50',
  '13:37:00', '13:37:10', '13:37:20', '13:37:30', '13:37:40', '13:37:50',
  '13:38:00', '13:38:10', '13:38:20', '13:38:30', '13:38:40', '13:38:50',
  '13:39:00', '13:39:10', '13:39:20', '13:39:30', '13:39:40', '13:39:50',
  '13:40:00', '13:40:10', '13:40:20', '13:40:30', '13:40:40', '13:40:50',
  '13:41:00', '13:41:10', '13:41:20', '13:41:30', '13:41:40', '13:41:50',
  '13:42:00', '13:42:10', '13:42:20', '13:42:30', '13:42:40', '13:42:50',
  '13:43:00', '13:43:10', '13:43:20', '13:43:30', '13:43:40', '13:43:50',
  '13:44:00', '13:44:10', '13:44:20', '13:44:30', '13:44:40', '13:44:50',
  '13:45:00', '13:45:10', '13:45:20', '13:45:30', '13:45:40', '13:45:50',
  '13:46:00', '13:46:10', '13:46:20', '13:46:30', '13:46:40', '13:46:50',
  '13:47:00', '13:47:10', '13:47:20', '13:47:30', '13:47:40', '13:47:50',
  '13:48:00', '13:48:10', '13:48:20', '13:48:30', '13:48:40', '13:48:50',
  '13:49:00', '13:49:10', '13:49:20', '13:49:30', '13:49:40', '13:49:50',
  '13:50:00', '13:50:10', '13:50:20', '13:50:30', '13:50:40', '13:50:50',
  '13:51:00', '13:51:10', '13:51:20', '13:51:30', '13:51:40', '13:51:50',
  '13:52:00', '13:52:10', '13:52:20', '13:52:30', '13:52:40', '13:52:50',
  '13:53:00', '13:53:10', '13:53:20', '13:53:30', '13:53:40', '13:53:50',
  '13:54:00', '13:54:10', '13:54:20', '13:54:30', '13:54:40', '13:54:50',
  '13:55:00', '13:55:10', '13:55:20', '13:55:30', '13:55:40', '13:55:50',
  '13:56:00', '13:56:10', '13:56:20', '13:56:30', '13:56:40', '13:56:50',
  '13:57:00', '13:57:10', '13:57:20', '13:57:30', '13:57:40', '13:57:50',
  '13:58:00', '13:58:10', '13:58:20', '13:58:30', '13:58:40', '13:58:50',
  '13:59:00', '13:59:10', '13:59:20', '13:59:30', '13:59:40', '13:59:50',
  '14:00:00', '14:00:10', '14:00:20', '14:00:30', '14:00:40', '14:00:50',
  '14:01:00', '14:01:10', '14:01:20', '14:01:30', '14:01:40', '14:01:50',
  '14:02:00', '14:02:10', '14:02:20', '14:02:30', '14:02:40', '14:02:50',
  '14:03:00', '14:03:10', '14:03:20', '14:03:30', '14:03:40', '14:03:50',
  '14:04:00', '14:04:10', '14:04:20', '14:04:30', '14:04:40', '14:04:50',
  '14:05:00', '14:05:10', '14:05:20', '14:05:30', '14:05:40', '14:05:50',
  '14:06:00', '14:06:10', '14:06:20', '14:06:30', '14:06:40', '14:06:50',
  '14:07:00', '14:07:10', '14:07:20', '14:07:30', '14:07:40', '14:07:50',
  '14:08:00', '14:08:10', '14:08:20', '14:08:30', '14:08:40', '14:08:50',
  '14:09:00', '14:09:10', '14:09:20', '14:09:30', '14:09:40', '14:09:50',
  '14:10:00', '14:10:10', '14:10:20', '14:10:30', '14:10:40', '14:10:50',
  '14:11:00', '14:11:10', '14:11:20', '14:11:30', '14:11:40', '14:11:50',
  '14:12:00', '14:12:10', '14:12:20', '14:12:30', '14:12:40', '14:12:50',
  '14:13:00', '14:13:10', '14:13:20', '14:13:30', '14:13:40', '14:13:50',
  '14:14:00', '14:14:10', '14:14:20', '14:14:30', '14:14:40', '14:14:50',
  '14:15:00', '14:15:10', '14:15:20', '14:15:30', '14:15:40', '14:15:50',
  '14:16:00', '14:16:10', '14:16:20', '14:16:30', '14:16:40', '14:16:50',
  '14:17:00', '14:17:10', '14:17:20', '14:17:30', '14:17:40', '14:17:50',
  '14:18:00', '14:18:10', '14:18:20', '14:18:30', '14:18:40', '14:18:50',
  '14:19:00', '14:19:10', '14:19:20', '14:19:30', '14:19:40', '14:19:50',
  '14:20:00', '14:20:10', '14:20:20', '14:20:30', '14:20:40', '14:20:50',
  '14:21:00', '14:21:10', '14:21:20', '14:21:30', '14:21:40', '14:21:50',
  '14:22:00', '14:22:10', '14:22:20', '14:22:30', '14:22:40', '14:22:50',
  '14:23:00', '14:23:10', '14:23:20', '14:23:30', '14:23:40', '14:23:50',
  '14:24:00', '14:24:10', '14:24:20', '14:24:30', '14:24:40', '14:24:50',
  '14:25:00', '14:25:10', '14:25:20', '14:25:30', '14:25:40', '14:25:50',
  '14:26:00', '14:26:10', '14:26:20', '14:26:30', '14:26:40', '14:26:50',
  '14:27:00', '14:27:10', '14:27:20', '14:27:30', '14:27:40', '14:27:50',
  '14:28:00', '14:28:10', '14:28:20', '14:28:30', '14:28:40', '14:28:50',
  '14:29:00', '14:29:10', '14:29:20', '14:29:30', '14:29:40', '14:29:50',
  '14:30:00', '14:30:10', '14:30:20', '14:30:30', '14:30:40', '14:30:50',
  '14:31:00', '14:31:10', '14:31:20', '14:31:30', '14:31:40', '14:31:50',
  '14:32:00', '14:32:10', '14:32:20', '14:32:30', '14:32:40', '14:32:50',
  '14:33:00', '14:33:10', '14:33:20', '14:33:30', '14:33:40', '14:33:50',
  '14:34:00', '14:34:10', '14:34:20', '14:34:30', '14:34:40', '14:34:50',
  '14:35:00', '14:35:10', '14:35:20', '14:35:30', '14:35:40', '14:35:50',
  '14:36:00', '14:36:10', '14:36:20', '14:36:30', '14:36:40', '14:36:50',
  '14:37:00', '14:37:10', '14:37:20', '14:37:30', '14:37:40', '14:37:50',
  '14:38:00', '14:38:10', '14:38:20', '14:38:30', '14:38:40', '14:38:50',
  '14:39:00', '14:39:10', '14:39:20', '14:39:30', '14:39:40', '14:39:50',
  '14:40:00', '14:40:10', '14:40:20', '14:40:30', '14:40:40', '14:40:50',
  '14:41:00', '14:41:10', '14:41:20', '14:41:30', '14:41:40', '14:41:50',
  '14:42:00', '14:42:10', '14:42:20', '14:42:30', '14:42:40', '14:42:50',
  '14:43:00', '14:43:10', '14:43:20', '14:43:30', '14:43:40', '14:43:50',
  '14:44:00', '14:44:10', '14:44:20', '14:44:30', '14:44:40', '14:44:50',
  '14:45:00', '14:45:10', '14:45:20', '14:45:30', '14:45:40', '14:45:50',
  '14:46:00', '14:46:10', '14:46:20', '14:46:30', '14:46:40', '14:46:50',
  '14:47:00', '14:47:10', '14:47:20', '14:47:30', '14:47:40', '14:47:50',
  '14:48:00', '14:48:10', '14:48:20', '14:48:30', '14:48:40', '14:48:50',
  '14:49:00', '14:49:10', '14:49:20', '14:49:30', '14:49:40', '14:49:50',
  '14:50:00', '14:50:10', '14:50:20', '14:50:30', '14:50:40', '14:50:50',
  '14:51:00', '14:51:10', '14:51:20', '14:51:30', '14:51:40', '14:51:50',
  '14:52:00', '14:52:10', '14:52:20', '14:52:30', '14:52:40', '14:52:50',
  '14:53:00', '14:53:10', '14:53:20', '14:53:30', '14:53:40', '14:53:50',
  '14:54:00', '14:54:10', '14:54:20', '14:54:30', '14:54:40', '14:54:50',
  '14:55:00', '14:55:10', '14:55:20', '14:55:30', '14:55:40', '14:55:50',
  '14:56:00', '14:56:10', '14:56:20', '14:56:30', '14:56:40', '14:56:50',
  '14:57:00', '14:57:10', '14:57:20', '14:57:30', '14:57:40', '14:57:50',
  '14:58:00', '14:58:10', '14:58:20', '14:58:30', '14:58:40', '14:58:50',
  '14:59:00', '14:59:10', '14:59:20', '14:59:30', '14:59:40', '14:59:50'

 ]







